prism.run(
    function hideExportsMain() {
        const config = $$get(mod, 'hideExportSettings');
        // Search command by title, return matches on searchTerm
        const isMatchingCommand = (item, searchTerm) => {
            const title = $$get(item, 'command.title');
            return (title && title.match(new RegExp(searchTerm, 'i')));
        }
        // Search and remove menu item
        const searchAndDestroyCommandMenuItem = (downloadMenuItem, searchTerm) => {
            const items = downloadMenuItem.items;
            for (let i = items.length - 1; i >= 0; i--) {
                if (isMatchingCommand(items[i], searchTerm)) {
                    items.splice(i, 1);
                }
            }
        }
        // Search menu item by caption
        const searchMenuItem = (items, searchTerm) => {
            if (!items) {
                return;
            }
            for (let i = 0; i < items.length; i++) {
                // Search download caption
                if (typeof items[i].caption === 'string' &&
                    items[i].caption.match(new RegExp(searchTerm, 'i'))) {
                    return items[i];
                }
            }
        }
        // Should entire download menu item be deleted?
        const deleteDownloadMenuItem = (downloadMenuItem) => {
            return !downloadMenuItem.items
                .filter((subMenu) => subMenu.type !== 'separator')
                .length;
        };
        /**
         * Main
         */
        const hideExportOptions = (s, args) => {
            const searchTerms = config.searchTerms.join('|');
            const downloadCaption = 'Download';
            if (config.supportedRoles.indexOf(prism.user.roleName) >= 0 ||
                config.supportedWidgets.indexOf($$get(args, 'settings.scope.widget.type')) === -1 ||
                !defined(args, 'settings.items')) {
                return;
            }
            const items = args.settings.items;
            if (prism.$ngscope.appstate === 'widget') {
                searchAndDestroyCommandMenuItem(items, searchTerms);
            } else {
                const downloadMenuItem = searchMenuItem(items, downloadCaption);
                if (downloadMenuItem && defined(downloadMenuItem, 'items')) {
                    searchAndDestroyCommandMenuItem(downloadMenuItem, searchTerms);
                }
                if (deleteDownloadMenuItem(downloadMenuItem)) {
                    const downloadMenuIdx = items.indexOf(downloadMenuItem);
                    items.splice(downloadMenuIdx, 2);
                }
            }
        }
        // Assign listener to beforemenu event
        prism.on('beforemenu', hideExportOptions);
    }
);